==> haskell-hslua-repl-0.1.2-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-repl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-repl
version:              0.1.2
visibility:           public
id:                   hslua-repl-0.1.2-BmXIGOIxKH75vJiAFkwOoJ
key:                  hslua-repl-0.1.2-BmXIGOIxKH75vJiAFkwOoJ
license:              MIT
copyright:            © 2023-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Isocline-based Lua REPL
description:          An embeddable Lua REPL built with Isocline and HsLua.
category:             Foreign
abi:                  39d618d578f15e143c947277f7930625
exposed:              True
exposed-modules:      HsLua.REPL
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-repl-0.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-repl-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-repl
hs-libraries:         HShslua-repl-0.1.2-BmXIGOIxKH75vJiAFkwOoJ
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    hslua-core-2.3.1-IyI9OufFuBtHH3ZMlxCaYs
    isocline-1.0.9-2dBQZhT1SqR1bCMBoLzGES
    lua-2.3.2-BzFGgQ9DVIwCkQiWvOAVka text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-hslua-repl/html/hslua-repl.haddock
haddock-html:         /usr/share/doc/haskell-hslua-repl/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-repl-0.1.2-18.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-repl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-repl
version:              0.1.2
visibility:           public
id:                   hslua-repl-0.1.2-C9lIZj2e7E6A6v7J5xFuHK
key:                  hslua-repl-0.1.2-C9lIZj2e7E6A6v7J5xFuHK
license:              MIT
copyright:            © 2023-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Isocline-based Lua REPL
description:          An embeddable Lua REPL built with Isocline and HsLua.
category:             Foreign
abi:                  06b9d75e6fe9d23b9f34f57b51081393
exposed:              True
exposed-modules:      HsLua.REPL
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-repl-0.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-repl-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-repl
hs-libraries:         HShslua-repl-0.1.2-C9lIZj2e7E6A6v7J5xFuHK
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    hslua-core-2.3.1-8C0aoFQaOrXKTRw02glTvW
    isocline-1.0.9-2dBQZhT1SqR1bCMBoLzGES
    lua-2.3.3-LJjSIwUOXmTId3gJRxtLsQ text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-hslua-repl/html/hslua-repl.haddock
haddock-html:         /usr/share/doc/haskell-hslua-repl/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
